@@ -21,7 +21,7 @@ def cmsApplications(request, *args):
     apps = []
 
     for name, factory in ptah.cms.get_app_factories().items():
-        root = factory(request)
+        root = factory()
 
         try:
             info = wrap(root).info()
@@ -275,10 +275,12 @@ def blobData(content, request, *args):
     response = request.response
 
     info = content.info()
-    response.content_type = info['mimetype']
+
+    headers = {'Content-Type': info['mimetype'].encode('utf-8')}
     if info['filename']:
-        response.headerlist = {
-            'Content-Disposition':
-            bytes_('filename="{0}"'.format(info['filename']), 'utf-8')}
+        headers['Content-Disposition'] = \
+            bytes_('filename="{0}"'.format(info['filename']), 'utf-8')
+
+    response.headers = headers
     response.body = content.read()
     return response
