@@ -57,7 +57,10 @@ from ptah.form.fields import TimezoneField
 # js fields (temporary)
 from ptah.form.jsfields import JSDateField
 from ptah.form.jsfields import JSDateTimeField
-from ptah.form.jsfields import TinymceField
+from ptah.form.jsfields import CKEditorField
+
+# backward compatibility
+#TinymceField = CKEditorField
 
 # helper field classes
 from ptah.form.fields import VocabularyField
@@ -84,3 +87,4 @@ from ptah.form.button import AC_PRIMARY
 from ptah.form.button import AC_DANGER
 from ptah.form.button import AC_SUCCESS
 from ptah.form.button import AC_INFO
+from ptah.form.button import AC_WARNING
