@@ -1,19 +1,20 @@
 import ptah
+from ptah.testing import PtahTestCase
 from pyramid.testing import DummyRequest
-
-from base import Base
+from pyramid.view import render_view_to_response
 
 
-class TestPermissionsModule(Base):
+class TestPermissionsModule(PtahTestCase):
 
     def test_perms_module(self):
-        from ptah.manage.manage import CONFIG, PtahManageRoute
+        from ptah.manage.manage import PtahManageRoute
         from ptah.manage.permissions import PermissionsModule
 
         request = DummyRequest()
 
-        ptah.authService.set_userid('test')
-        CONFIG['managers'] = ('*',)
+        ptah.auth_service.set_userid('test')
+        cfg = ptah.get_settings(ptah.CFG_ID_PTAH, self.registry)
+        cfg['managers'] = ('*',)
         mr = PtahManageRoute(request)
         mod = mr['permissions']
 
@@ -26,7 +27,7 @@ class TestPermissionsModule(Base):
 
         mod = PermissionsModule(None, request)
 
-        res = PermissionsView.__renderer__(mod, request)
+        res = render_view_to_response(mod, request, '', False)
         self.assertEqual(res.status, '200 OK')
 
     def test_perms_roles(self):
@@ -36,5 +37,6 @@ class TestPermissionsModule(Base):
 
         mod = PermissionsModule(None, request)
 
-        res = RolesView.__renderer__(mod, request)
+        res = render_view_to_response(mod, request, 'roles.html', False)
         self.assertEqual(res.status, '200 OK')
+        self.assertIn('<h2>Roles</h2>', res.text)
