@@ -296,7 +296,7 @@ class TestSettings(BaseTesting):
             ptah.config.StopException,
             get_settings_ob().init,
             self.config,
-            {'group.node1': '1,l'})
+            {'group.node1': 'l,1'})
 
     def test_settings_init_with_no_loader_with_defaults(self):
         group = self._create_default_group()
@@ -524,8 +524,15 @@ class TestDBSettings(TestDBSettingsBase):
         for rec in Session.query(SettingRecord):
             res[rec.name] = rec.value
 
-        self.assertEqual(len(res), 2)
-        self.assertNotIn('group.node3', res)
+        self.assertEqual(len(res), 3)
+        self.assertEqual(res['group.node3'], '500')
+
+        grp['node3'] = 600
+        self.assertEqual(grp['node3'], 600)
+
+        settings = self.config.get_cfg_storage('ptah:settings')
+        settings.load_fromdb()
+        self.assertEqual(grp['node3'], 500)
 
     def test_settings_updatedb_partial(self):
         grp = self._make_grp()
@@ -582,6 +589,9 @@ class TestDBSettings(TestDBSettingsBase):
         from ptah.settings import SettingRecord
         Session = ptah.get_session()
 
+        # non json obj
+        Session.add(SettingRecord(name='group.node3', value='value'))
+
         settings = self.registry.__ptah_storage__[SETTINGS_OB_ID]
         settings.load({})
 
@@ -592,6 +602,8 @@ class TestDBSettings(TestDBSettingsBase):
         self.assertEqual(grp['node1'], 'new text')
         self.assertEqual(grp['node2'], 65)
 
+        self.assertEqual(grp['node3'], 'value')
+
     def test_settings_load_from_db_on_startup(self):
         grp = self._make_grp()
 
