@@ -1,8 +1,31 @@
 import ptah
 import threading
-from datetime import timedelta
+from datetime import datetime, timedelta
 from pyramid.interfaces import INewRequest
 
+def dthandler(obj):
+    return obj.isoformat() if isinstance(obj, datetime) else None
+
+kwargs = {'default': dthandler, 'separators': (',', ':')}
+
+# Faster
+try:
+    import simplejson as jsonmod
+except ImportError: #pragma: no cover
+    # Slowest
+    import json as jsonmod
+
+class json(object):
+
+    @staticmethod
+    def dumps(o, **kw):
+        kw.update(kwargs)
+        return jsonmod.dumps(o, **kw)
+
+    @staticmethod
+    def loads(s, **kw):
+        return jsonmod.loads(s, **kw)
+
 
 class ThreadLocalManager(threading.local):
 
